package com.yunzhi.inte.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.inte.common.ResponseBean;
import com.yunzhi.inte.entity.Banner;
import com.yunzhi.inte.entity.Info;
import com.yunzhi.inte.service.BannerService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

@RestController
@RequestMapping("/")
public class BannerController {
    private final Logger logger = LoggerFactory.getLogger(InfoController.class);

    @Autowired
    public BannerService bannerService;

    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/banner",method= RequestMethod.GET)
    public ResponseBean BannerPage(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                             @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize) throws Exception{

        IPage<Banner> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<Info> queryWrapper = new QueryWrapper<>();
        queryWrapper.orderByDesc("qz");

        IPage<Banner> result = bannerService.page(pg);
        return ResponseBean.success(result);
    }

    /**
     * 增加
     * @param Banner 实体对象
     * @return
     */
    @RequestMapping(value="/banner",method= RequestMethod.POST)
    public ResponseBean BannerAdd(@RequestBody Banner banner) throws Exception{

        if (bannerService.save(banner)){
            return ResponseBean.success(banner);
        }else {
            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @RequestMapping(value="/banner/{id}", method= RequestMethod.DELETE)
    public ResponseBean BannerDelete(@PathVariable Integer id) throws Exception{
        if(bannerService.removeById(id)){
            return ResponseBean.success("success");
        }else {
            return ResponseBean.error("删除失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param Banner 实体对象
     * @return
     */
    @RequestMapping(value="/banner/{id}",method= RequestMethod.PUT)
    public ResponseBean BannerUpdate(@PathVariable Integer id,
                                     @RequestBody Banner banner) throws Exception{
        banner.setId(id);
        if (bannerService.updateById(banner)){
            return ResponseBean.success(bannerService.getById(id));
        }else {
            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/banner/{id}",method= RequestMethod.GET)
    public ResponseBean BannerId(@PathVariable Integer id) throws Exception{
        return ResponseBean.success(bannerService.getById(id));
    }
}
